@@ -1,5 +1,5 @@
 
-from smtpd import server
+from pymail.pymail import server
 import os
 from unittest import TestCase
 
@@ -9,8 +9,8 @@ class ServerHelpTest(TestCase):
             s = server.Server(['-h'])
 
 def testCreateServer():
-    s = server.Server(['-c', os.getcwd() + '/test/config0'])
+    s = server.Server(['-c', os.path.join(os.getcwd(), 'test', 'config0')])
 
 def testStartServer():
-    s = server.Server(['-c', os.getcwd() + '/test/config1'])
-    s.start()
+    s = server.Server(['-c', os.path.join(os.getcwd(), 'test', 'config1')])
+    s.start(False)
