@@ -2,8 +2,8 @@
 Test sinks
 '''
 
-from smtpd import sink, configuration
-from smtpd.debug import D
+from pymail.pymail import sink, configuration
+from pymail.pymail.debug import D
 
 def testSmtpSink():
     config = configuration.DictMapper({})
